@@ -46,6 +46,7 @@
 #define HAVE_SYS_SENDFILE_H 1
 #define HAVE_SYS_SOCKET_H 1
 #define HAVE_SYS_SYSCALL_H 1
+#define HAVE_SYS_SYSMACROS_H 1
 #define HAVE_SYS_TIME_H 1
 #define HAVE_SYS_TIMES_H 1
 #define HAVE_SYS_UIO_H 1
@@ -63,6 +64,7 @@
 #define SIZEOF_LONG 8
 #define SIZEOF_LONG_LONG 8
 #define SIZEOF___INT64 0
+#define SIZEOF___INT128 16
 #define SIZEOF_OFF_T 8
 #define SIZEOF_VOIDP 8
 #define SIZEOF_FLOAT 4
@@ -122,22 +124,29 @@
 #define STRINGIZE(expr) STRINGIZE0(expr)
 #define HAVE_STDARG_PROTOTYPES 1
 #define HAVE_VA_ARGS_MACRO 1
-#define NORETURN(x) __attribute__ ((noreturn)) x
-#define DEPRECATED(x) __attribute__ ((deprecated)) x
-#define DEPRECATED_BY(n,x) __attribute__ ((deprecated("by "#n))) x
-#define DEPRECATED_TYPE(mesg,x) __attribute__ ((deprecated mesg)) x
-#define NOINLINE(x) __attribute__ ((noinline)) x
-#define WEAK(x) __attribute__ ((weak)) x
+#define CONSTFUNC(x) __attribute__ ((__const__)) x
+#define PUREFUNC(x) __attribute__ ((__pure__)) x
+#define NORETURN(x) __attribute__ ((__noreturn__)) x
+#define DEPRECATED(x) __attribute__ ((__deprecated__)) x
+#define DEPRECATED_BY(n,x) __attribute__ ((__deprecated__("by "#n))) x
+#define DEPRECATED_TYPE(mesg,x) __attribute__ ((__deprecated__ mesg)) x
+#define NOINLINE(x) __attribute__ ((__noinline__)) x
+#define ALWAYS_INLINE(x) __attribute__ ((__always_inline__)) x
+#define WARN_UNUSED_RESULT(x) __attribute__ ((__warn_unused_result__)) x
+#define MAYBE_UNUSED(x) __attribute__ ((__unused__)) x
+#define ERRORFUNC(mesg,x) __attribute__ ((__error__ mesg)) x
+#define WARNINGFUNC(mesg,x) __attribute__ ((__warning__ mesg)) x
+#define WEAK(x) __attribute__ ((__weak__)) x
 #define HAVE_FUNC_WEAK 1
-#define FUNC_UNOPTIMIZED(x) __attribute__ ((optimize("O0"))) x
-#define FUNC_MINIMIZED(x) __attribute__ ((optimize("-Os","-fomit-frame-pointer"))) x
+#define FUNC_UNOPTIMIZED(x) __attribute__ ((__optimize__("O0"))) x
+#define FUNC_MINIMIZED(x) __attribute__ ((__optimize__("-Os","-fomit-frame-pointer"))) x
 #define HAVE_ATTRIBUTE_FUNCTION_ALIAS 1
 #define RUBY_ALIAS_FUNCTION_TYPE(type, prot, name, args) type prot __attribute__((alias(#name)));
 #define RUBY_ALIAS_FUNCTION_VOID(prot, name, args) RUBY_ALIAS_FUNCTION_TYPE(void, prot, name, args)
 #define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_SYNC_BUILTINS 1
 #define UNREACHABLE __builtin_unreachable()
-#define RUBY_FUNC_EXPORTED __attribute__ ((visibility("default"))) extern
+#define RUBY_FUNC_EXPORTED __attribute__ ((__visibility__("default"))) extern
 #define RUBY_FUNCTION_NAME_STRING __func__
 #define ENUM_OVER_INT 1
 #define HAVE_DECL_SYS_NERR 1
@@ -180,6 +189,12 @@
 #define SIZEOF_INT64_T 8
 #define HAVE_UINT64_T 1
 #define SIZEOF_UINT64_T 8
+#define HAVE_INT128_T 1
+#define int128_t __int128
+#define SIZEOF_INT128_T SIZEOF___INT128
+#define HAVE_UINT128_T 1
+#define uint128_t unsigned __int128
+#define SIZEOF_UINT128_T SIZEOF___INT128
 #define HAVE_INTPTR_T 1
 #define SIZEOF_INTPTR_T 8
 #define HAVE_UINTPTR_T 1
@@ -216,12 +231,12 @@
 #define HAVE_WORKING_VFORK 1
 #define HAVE_WORKING_FORK 1
 #define HAVE__LONGJMP 1
-#define HAVE__SETJMP 1
 #define HAVE_ATAN2L 1
 #define HAVE_ATAN2F 1
 #define HAVE_CHROOT 1
 #define HAVE_CLOCK_GETTIME 1
 #define HAVE_COSH 1
+#define HAVE_CRYPT_R 1
 #define HAVE_DIRFD 1
 #define HAVE_DL_ITERATE_PHDR 1
 #define HAVE_DLOPEN 1
@@ -315,12 +330,19 @@
 #define HAVE_UTIMES 1
 #define HAVE_WAIT4 1
 #define HAVE_WAITPID 1
+#define HAVE_CRYPT_H 1
+#define HAVE_STRUCT_CRYPT_DATA_INITIALIZED 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP16 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP32 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP64 1
+#define HAVE_BUILTIN___BUILTIN_POPCOUNT 1
+#define HAVE_BUILTIN___BUILTIN_POPCOUNTLL 1
 #define HAVE_BUILTIN___BUILTIN_CLZ 1
 #define HAVE_BUILTIN___BUILTIN_CLZL 1
 #define HAVE_BUILTIN___BUILTIN_CLZLL 1
+#define HAVE_BUILTIN___BUILTIN_CTZ 1
+#define HAVE_BUILTIN___BUILTIN_CTZLL 1
+#define HAVE_BUILTIN___BUILTIN_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
@@ -337,6 +359,7 @@
 #define TIMEZONE_VOID 1
 #define NEGATIVE_TIME_T 1
 #define POSIX_SIGNAL 1
+#define HAVE_SIG_T 1
 #define RSHIFT(x,y) ((x)>>(int)(y))
 #define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
@@ -364,6 +387,7 @@
 #define DLEXT_MAXLEN 3
 #define DLEXT ".so"
 #define LIBDIR_BASENAME "lib"
+#define HAVE__SETJMP 1
 #define RUBY_SETJMP(env) __builtin_setjmp((env))
 #define RUBY_LONGJMP(env,val) __builtin_longjmp((env),val)
 #define RUBY_JMP_BUF jmp_buf
